![](./KlayLogo.png)
# KLay - KLIFF Layers, trainable and pre-trained layers for MLIPs
[![Documentation Status](https://readthedocs.org/projects/klay/badge/?version=latest)](https://klay.readthedocs.io/en/latest/?badge=latest)
 
KLIFF compatible ML layers you can mould to your needs. Usable for general neural network architectures as well. Works out of the box with KLIFF.


